@@ -538,11 +538,6 @@ eog_full_screen_key_press (GtkWidget *widget, GdkEventKey *event)
 	}
 
 	if (do_hide) {
-		cancel_load_by_iter (priv->list, priv->preload);
-		if (priv->preload != NULL) {
-			g_free (priv->preload);
-			priv->preload = NULL;
-		}
 		gtk_widget_hide (widget);
 	}
 
@@ -697,12 +692,6 @@ job_image_load_finished  (EogJob *job, gpointer data, GError *error)
 	EogImage *current_img;
 	EogImage *preload_img;
 
-	if (eog_job_get_status (job) == EOG_JOB_STATUS_CANCELED) {
-		g_object_set_qdata (G_OBJECT (image), JOB_ID_QUARK, NULL);
-		eog_image_data_unref (image);
-		return;
-	}
-
 	if (eog_job_get_success (job))
 		eog_image_cache_add (priv->cache, image);
 
@@ -819,7 +808,6 @@ eog_full_screen_new (GtkWindow *parent,
 	GConfClient   *client;
 	gboolean       upscale = TRUE;
 	gboolean       antialiasing = TRUE;
-	gchar         *transparency;
 
 	g_return_val_if_fail (image_list != NULL, NULL);
 
@@ -840,7 +828,7 @@ eog_full_screen_new (GtkWindow *parent,
 	style->bg    [GTK_STATE_NORMAL] = style->black;
 	style->bg_gc [GTK_STATE_NORMAL] = style->black_gc;
 	if (style->bg_pixmap [GTK_STATE_NORMAL])
-		g_object_unref (style->bg_pixmap [GTK_STATE_NORMAL]);
+		gdk_pixmap_unref (style->bg_pixmap [GTK_STATE_NORMAL]);
 	style->bg_pixmap [GTK_STATE_NORMAL] = NULL;
 
 	gtk_widget_set_style (widget, style);
@@ -860,29 +848,9 @@ eog_full_screen_new (GtkWindow *parent,
 	priv->switch_timeout = gconf_client_get_int (client, EOG_CONF_FULLSCREEN_SECONDS, NULL);
 	upscale = gconf_client_get_bool (client, EOG_CONF_FULLSCREEN_UPSCALE, NULL);
 	antialiasing = gconf_client_get_bool (client, EOG_CONF_VIEW_INTERPOLATE, NULL);
-	transparency = gconf_client_get_string (client, EOG_CONF_VIEW_TRANSPARENCY, NULL);
 	eog_scroll_view_set_zoom_upscale (EOG_SCROLL_VIEW (widget), upscale);
 	eog_scroll_view_set_antialiasing (EOG_SCROLL_VIEW (widget), antialiasing);
-	if (g_strcasecmp (transparency, "COLOR") == 0) {
-		gchar *trans_color;
-		GdkColor color;
-		
-		trans_color = gconf_client_get_string (client, EOG_CONF_VIEW_TRANS_COLOR, NULL);
-		if (gdk_color_parse (trans_color, &color))
-			eog_scroll_view_set_transparency (EOG_SCROLL_VIEW (widget),
-							  TRANSP_COLOR, &color);
-
-		if (trans_color)
-			g_free (trans_color);
-	}
-	else if (g_strcasecmp (transparency, "CHECK_PATTERN") == 0) 
-		eog_scroll_view_set_transparency (EOG_SCROLL_VIEW (widget),
-						  TRANSP_CHECKED, 0);
-	else 
-		eog_scroll_view_set_transparency (EOG_SCROLL_VIEW (widget),
-						  TRANSP_BACKGROUND, 0);
-	if(transparency)	
-		g_free(transparency);
+	
 	g_object_unref (G_OBJECT (client));
 
 	/* load first image in the background */
